@@ -1,6 +1,7 @@
 """Collection of helpers methods that help to style tables in Jupyter Notebooks
 """
-from typing import Union, Optional, List
+from __future__ import annotations
+from typing import TypeVar
 from html import escape
 
 import pandas as pd
@@ -18,21 +19,24 @@ import helpsk.pandas as pandas
 from helpsk.validation import any_none_nan
 
 
-def format(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler"],  # noqa
-           subset: Optional[List[str]] = None,
+Subset = TypeVar('Subset')
+
+
+def format(styler: pd.DataFrame | Styler,
+           subset: list[str] | None = None,
            round_by: int = 2,
-           fill_missing_value: Optional[str] = '<NA>',
-           missing_color: Optional[str] = color.WARNING,
-           thousands: Optional[str] = ',',
+           fill_missing_value: str | None = '<NA>',
+           missing_color: str | None = color.WARNING,
+           thousands: str | None = ',',
            hide_index: bool = False) -> Styler:
     """Applies basic formatting to pandas Dataframe.
     Args:
         styler:
             either pd.Dataframe or pd.Dataframe.style
         subset:
-            A valid 2d input to DataFrame.loc[<subset>], or, in the case of a 1d input or single key,
-            to DataFrame.loc[:, <subset>] where the columns are prioritised, to limit data to before applying
-            the function.
+            A valid 2d input to DataFrame.loc[<subset>], or, in the case of a 1d input or single
+            key, to DataFrame.loc[:, <subset>] where the columns are prioritised, to limit data to
+            before applying the function.
         round_by:
             number of digits to round numeric columns to
         fill_missing_value:
@@ -40,8 +44,8 @@ def format(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler"],  # noq
         missing_color:
             The background color for cells that have missing values.
         thousands:
-            the separator used for thousands e.g. `'` will result in `10,000` while ` ` will result in
-            `10 000`.
+            the separator used for thousands e.g. `'` will result in `10,000` while ` ` will
+            result in `10 000`.
         hide_index:
             Hide the index of the dataframe.
     Returns:
@@ -51,8 +55,7 @@ def format(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler"],  # noq
     if isinstance(styler, pd.DataFrame):
         styler = styler.style
 
-    if missing_color:
-        styler = styler.highlight_null(null_color=missing_color)
+    styler = styler.highlight_null(missing_color)
 
     if hide_index:
         styler = styler.hide(axis='index')
@@ -63,9 +66,7 @@ def format(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler"],  # noq
                          thousands=thousands)  # noqa
 
 
-def background_color(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler"],  # noqa,
-                     palette: str = 'Blues',
-                     **kwargs) -> Styler:
+def background_color(styler: pd.DataFrame | Styler, palette: str = 'Blues', **kwargs) -> Styler:
     """Applies a background color to pandas Dataframe.
         Args:
             styler:
@@ -73,7 +74,8 @@ def background_color(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler
             palette:
                 name of the palette (value passed into seaborn `color_palette()`
             kwargs:
-                additional arguments that will be passed to the pandas `.background_gradient()` function.
+                additional arguments that will be passed to the pandas `.background_gradient()`
+                function.
         Returns:
             styler
         """
@@ -88,8 +90,13 @@ def background_color(styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler
     return styler.background_gradient(cmap=color_map, **kwargs)
 
 
-def __bar_inverse(style_object, align: str, colors: list[str], width: float = 100, min_value: float = None,
-                  max_value: float = None):
+def __bar_inverse(
+        style_object,
+        align: str,
+        colors: list[str],
+        width: float = 100,
+        min_value: float = None,
+        max_value: float = None) -> pd.DataFrame:
     """
     CODE MODIFIED FROM
         https://github.com/pandas-dev/pandas/blob/v1.3.2/pandas/io/formats/style.py#L2178-L2258
@@ -107,10 +114,12 @@ def __bar_inverse(style_object, align: str, colors: list[str], width: float = 10
         object_max = max(abs(object_min), abs(object_max))
         object_min = -object_max
     # Transform to percent-range of linear-gradient
-    normed = width * (style_object.to_numpy(dtype=float) - object_min) / (object_max - object_min + 1e-12)
+    normed = width \
+        * (style_object.to_numpy(dtype=float) - object_min) \
+        / (object_max - object_min + 1e-12)
     zero = -width * object_min / (object_max - object_min + 1e-12)
 
-    def css_bar(start: float, end: float, color: str) -> str:  # noqa
+    def css_bar(start: float, end: float, color: str) -> str:
         """
         Generate CSS code to draw a bar from start to end.
         """
@@ -151,8 +160,8 @@ def __bar_inverse(style_object, align: str, colors: list[str], width: float = 10
 
 
 def bar_inverse(
-        styler: Union[pd.DataFrame, "pandas.io.formats.style.Styler"],  # noqa
-        subset: "Subset" = None,  # noqa
+        styler: pd.DataFrame | Styler,
+        subset: Subset = None,
         axis: Axis = 0,
         color="#d65f5f",
         width: float = 100,
@@ -237,7 +246,7 @@ def bar_inverse(
     return styler
 
 
-def html_escape_dataframe(dataframe: pd.DataFrame):
+def html_escape_dataframe(dataframe: pd.DataFrame) -> pd.DataFrame:
     """HTML `escapes` all string and categorical columns and indexes in the `dataframe`.
 
     This can be used when displaying pd.DataFrames in Jupyter notebook using `.style`;
@@ -246,7 +255,8 @@ def html_escape_dataframe(dataframe: pd.DataFrame):
     Args:
         pd.DataFrame
     Returns:
-        a copy of the `dataframe` with string values replaced after being html encoded via `html.escape()`
+        a copy of the `dataframe` with string values replaced after being html encoded via
+        `html.escape()`
     """
     def __escape(value):
         if not any_none_nan([value]) and isinstance(value, str):
@@ -255,7 +265,8 @@ def html_escape_dataframe(dataframe: pd.DataFrame):
         return value
 
     dataframe = dataframe.copy()
-    columns_to_escape = pandas.get_string_columns(dataframe) + pandas.get_categorical_columns(dataframe)
+    columns_to_escape = pandas.get_string_columns(dataframe) + \
+        pandas.get_categorical_columns(dataframe)
     for column in columns_to_escape:
         dataframe[column] = dataframe[column].apply(__escape)
 
